<?php
/**
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 */


if ( ! function_exists( 'bizness_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
function bizness_setup() {
		
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 */
	load_theme_textdomain( 'bizness', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'bizness' ),
	) );

	add_theme_support('post-thumbnails'); 
	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();
	
	
	// custom backgrounds
	$bizness_custom_background = array(
		// Background color default
		'default-color' => 'e4e4e4',
		// Background image default
		'default-image' => '',
		'wp-head-callback' => '_custom_background_cb'
	);
	add_theme_support('custom-background', $bizness_custom_background );

	
	// adding post format support
	add_theme_support( 'post-formats', 
		array( 
			'aside', /* Typically styled without a title. Similar to a Facebook note update */
			'gallery', /* A gallery of images. Post will likely contain a gallery shortcode and will have image attachments */
			'link', /* A link to another site. Themes may wish to use the first <a href=ÓÓ> tag in the post content as the external link for that post. An alternative approach could be if the post consists only of a URL, then that will be the URL and the title (post_title) will be the name attached to the anchor for it */
			'image', /* A single image. The first <img /> tag in the post could be considered the image. Alternatively, if the post consists only of a URL, that will be the image URL and the title of the post (post_title) will be the title attribute for the image */
			'quote', /* A quotation. Probably will contain a blockquote holding the quote content. Alternatively, the quote may be just the content, with the source/author being the title */
			'status', /*A short status update, similar to a Twitter status update */
			'video', /* A single video. The first <video /> tag or object/embed in the post content could be considered the video. Alternatively, if the post consists only of a URL, that will be the video URL. May also contain the video as an attachment to the post, if video support is enabled on the blog (like via a plugin) */
			'audio', /* An audio file. Could be used for Podcasting */
			'chat' /* A chat transcript */
		)
	);
}
endif;
add_action( 'after_setup_theme', 'bizness_setup' );

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! function_exists( 'bizness_content_width' ) ) :
	function bizness_content_width() {
		global $content_width;
		if (!isset($content_width))
			$content_width = 550; /* pixels */
	}
endif;
add_action( 'after_setup_theme', 'bizness_content_width' );


/**
 * Title filter 
 */
if ( ! function_exists( 'bizness_filter_wp_title' ) ) :

	function bizness_filter_wp_title( $old_title, $sep, $sep_location ) {
	
		$site_name = get_bloginfo( 'name' );
		$site_description = get_bloginfo( 'description' );
		// add padding to the sep
		$ssep = ' ' . $sep . ' ';
		
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			return $site_name . ' | ' . $site_description;
		} else {
			// find the type of index page this is
			if( is_category() ) $insert = $ssep . __( 'Category', 'bizness' );
			elseif( is_tag() ) $insert = $ssep . __( 'Tag', 'bizness' );
			elseif( is_author() ) $insert = $ssep . __( 'Author', 'bizness' );
			elseif( is_year() || is_month() || is_day() ) $insert = $ssep . __( 'Archives', 'bizness' );
			else $insert = NULL;
			 
			// get the page number we're on (index)
			if( get_query_var( 'paged' ) )
			$num = $ssep . __( 'Page ', 'bizness' ) . get_query_var( 'paged' );
			 
			// get the page number we're on (multipage post)
			elseif( get_query_var( 'page' ) )
			$num = $ssep . __( 'Page ', 'bizness' ) . get_query_var( 'page' );
			 
			// else
			else $num = NULL;
			 
			// concoct and return new title
			return $site_name . $insert . $old_title . $num;
			
		}
	}
	
endif;
// call our custom wp_title filter, with normal (10) priority, and 3 args
add_filter( 'wp_title', 'bizness_filter_wp_title', 10, 3 );

/*******************************************************************
* These are settings for the Theme Customizer in the admin panel. 
*******************************************************************/
if ( ! function_exists( 'bizness_theme_customizer' ) ) :

	function bizness_theme_customizer( $wp_customize ) {
		
		$wp_customize->remove_section( 'title_tagline');
		$wp_customize->remove_section( 'static_front_page' );
	
	
		/* color scheme option */
		$wp_customize->add_setting( 'bizness_color_one', array (
			'default'	=> '#12b0e6',
		) );
		
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bizness_color_one', array(
			'label'    => __( 'Theme Color 1', 'bizness' ),
			'section'  => 'colors',
			'settings' => 'bizness_color_one',
		) ) );
		
		$wp_customize->add_setting( 'bizness_color_two', array (
			'default'	=> '#f6ad08',
		) );
		
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'bizness_color_two', array(
			'label'    => __( 'Theme Color 2', 'bizness' ),
			'section'  => 'colors',
			'settings' => 'bizness_color_two',
		) ) );
		
		/* logo option */
		$wp_customize->add_section( 'bizness_logo_section' , array(
			'title'       => __( 'Site Logo', 'bizness' ),
			'priority'    => 31,
			'description' => __( 'Upload a logo to replace the default site name in the header', 'bizness' ),
		) );
		
		$wp_customize->add_setting( 'bizness_logo' );
		
		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'bizness_logo', array(
			'label'    => __( 'Choose your logo (ideal width is 100-300px and ideal height is 40-100px)', 'bizness' ),
			'section'  => 'bizness_logo_section',
			'settings' => 'bizness_logo',
		) ) );
	
		
		/* social media option */
		$wp_customize->add_section( 'bizness_social_section' , array(
			'title'       => __( 'Social Media Icons', 'bizness' ),
			'priority'    => 32,
			'description' => __( 'Optional media icons in the header', 'bizness' ),
		) );
		
		$wp_customize->add_setting( 'bizness_facebook' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_facebook', array(
			'label'    => __( 'Enter your Facebook url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_facebook',
			'priority'    => 101,
		) ) );
	
		$wp_customize->add_setting( 'bizness_twitter' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_twitter', array(
			'label'    => __( 'Enter your Twitter url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_twitter',
			'priority'    => 102,
		) ) );
		
		$wp_customize->add_setting( 'bizness_google' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_google', array(
			'label'    => __( 'Enter your Google+ url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_google',
			'priority'    => 103,
		) ) );
		
		$wp_customize->add_setting( 'bizness_pinterest' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_pinterest', array(
			'label'    => __( 'Enter your Pinterest url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_pinterest',
			'priority'    => 104,
		) ) );
		
		$wp_customize->add_setting( 'bizness_linkedin' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_linkedin', array(
			'label'    => __( 'Enter your Linkedin url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_linkedin',
			'priority'    => 105,
		) ) );
		
		$wp_customize->add_setting( 'bizness_youtube' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_youtube', array(
			'label'    => __( 'Enter your Youtube url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_youtube',
			'priority'    => 106,
		) ) );
		
		$wp_customize->add_setting( 'bizness_tumblr' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_tumblr', array(
			'label'    => __( 'Enter your Tumblr url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_tumblr',
			'priority'    => 107,
		) ) );
		
		$wp_customize->add_setting( 'bizness_instagram' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_instagram', array(
			'label'    => __( 'Enter your Instagram url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_instagram',
			'priority'    => 108,
		) ) );
		
		$wp_customize->add_setting( 'bizness_flickr' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_flickr', array(
			'label'    => __( 'Enter your Flickr url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_flickr',
			'priority'    => 109,
		) ) );
		
		$wp_customize->add_setting( 'bizness_vimeo' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_vimeo', array(
			'label'    => __( 'Enter your Vimeo url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_vimeo',
			'priority'    => 110,
		) ) );
		
		$wp_customize->add_setting( 'bizness_rss' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_rss', array(
			'label'    => __( 'Enter your RSS url', 'bizness' ),
			'section'  => 'bizness_social_section',
			'settings' => 'bizness_rss',
			'priority'    => 111,
		) ) );
		
	
		
		/* slider options */
		
		$wp_customize->add_section( 'bizness_slider_section' , array(
			'title'       => __( 'Slider Options', 'bizness' ),
			'priority'    => 33,
			'description' => __( 'Adjust the behavior of the image slider.', 'bizness' ),
		) );
		
		$wp_customize->add_setting( 'bizness_slider_effect', array(
			'default' => 'scrollHorz',
			'capability' => 'edit_theme_options',
		));
		
		 $wp_customize->add_control( 'effect_select_box', array(
			'settings' => 'bizness_slider_effect',
			'label' => __( 'Select Effect:', 'bizness' ),
			'section' => 'bizness_slider_section',
			'type' => 'select',
			'choices' => array(
				'scrollHorz' => 'Horizontal (Default)',
				'scrollVert' => 'Vertical',
				'tileSlide' => 'Tile Slide',
				'tileBlind' => 'Blinds',
			),
		));
		
		$wp_customize->add_setting( 'bizness_slider_timeout' );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'bizness_slider_timeout', array(
			'label'    => __( 'Autoplay Speed in Seconds (0 for Manual)', 'bizness' ),
			'section'  => 'bizness_slider_section',
			'settings' => 'bizness_slider_timeout',
		) ) );
		
	}
	
endif;
add_action('customize_register', 'bizness_theme_customizer');

/**
* Apply Color Scheme
*/
if ( ! function_exists( 'bizness_apply_color' ) ) :

	function bizness_apply_color() {
		if ( get_theme_mod('bizness_color_one') ) {
	?>
		<style id="color-one" type="text/css">
			a, a:visited,
			.entry-title a,
			.post_content ol li:before,
			.post_content ul li:before,
			.commentlist .bypostauthor > article > footer > .vcard cite.fn:after,
			.commentlist .bypostauthor > article > footer > .vcard cite.fn,
			.cycle-pager span.cycle-pager-active { 
				color: <?php echo get_theme_mod('bizness_color_one'); ?>;
			}
			
	
			#social-media a,
			#search-icon,
			header[role=banner] #searchform input[type=submit],
			.pagination span, 
			.pagination a,
			footer[role=contentinfo] {
				background-color: <?php echo get_theme_mod('bizness_color_one'); ?>;
			}
				.pagination span, 
				.pagination a,
				footer[role=contentinfo] a {
					color: #fff;
				}
			
			.post_content pre { 
				border-left-color: <?php echo get_theme_mod('bizness_color_one'); ?>;
			}
		</style>
	<?php
		}
		
		if ( get_theme_mod('bizness_color_two') ) {
	?>
		<style id="color-two" type="text/css">
			.entry-meta a,
			.commentlist .vcard cite.fn a,
			#sidebar .widget-title,
			#sidebar-home .widget-title,
			.color2txt { 
				color: <?php echo get_theme_mod('bizness_color_two'); ?>;
			}
	
			nav[role=navigation] .menu ul li a:hover,
			nav[role=navigation] .menu ul li.current-menu-item a, 
			.nav ul li.current_page_item a, 
			nav[role=navigation] .menu ul li.current_page_item a,
			.comments-link a,
			#respond #submit,
			.pagination a:hover,
			.pagination .current {
				background-color: <?php echo get_theme_mod('bizness_color_two'); ?>;
			}
				.comments-link a {
					color: #fff;
				}
			
			#sidebar .widget-title,
			#sidebar-home .widget-title {
				border-bottom: 1px solid <?php echo get_theme_mod('bizness_color_two'); ?>;
			}
			
			@media only screen and (max-width: 824px) {
				
				nav[role=navigation] .menu ul li a {
					color: #2c383b;
				}
				
				nav[role=navigation] .menu ul li a:hover,	
				nav[role=navigation] .menu ul li.current-menu-item a, 
				.nav ul li.current_page_item a, 
				nav[role=navigation] .menu ul li.current_page_item a {
					background: #f2f2f2;
					color: #2c383b;
				}
	
			}
	
		</style>
	<?php
		}
	}
endif;
add_action( 'wp_head', 'bizness_apply_color' );


/**
* Filter the RSS Feed Site Title
*/
if ( ! function_exists( 'bizness_blogname_rss' ) ) :
	function bizness_blogname_rss( $val, $show ) {
		if( 'name' == $show )
			$out = '';
		else
			$out = $val;
	
		return $out;
	}
endif;
add_filter('bloginfo_rss', 'bizness_blogname_rss', 10, 2);




/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
if ( ! function_exists( 'bizness_main_nav' ) ) :
function bizness_main_nav() {
	// display the wp3 menu if available
    wp_nav_menu( 
    	array( 
    		'menu' => '', /* menu name */
    		'theme_location' => 'primary', /* where in the theme it's assigned */
    		'container_class' => 'menu', /* container class */
    		'fallback_cb' => 'bizness_main_nav_fallback' /* menu fallback */
    	)
    );
}
endif;

if ( ! function_exists( 'bizness_main_nav_fallback' ) ) :
	function bizness_main_nav_fallback() { wp_page_menu( 'show_home=Home&menu_class=menu' ); }
endif;

if ( ! function_exists( 'bizness_enqueue_comment_reply' ) ) :
	function bizness_enqueue_comment_reply() {
			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
					wp_enqueue_script( 'comment-reply' );
			}
	 }
endif;
add_action( 'comment_form_before', 'bizness_enqueue_comment_reply' );

if ( ! function_exists( 'bizness_page_menu_args' ) ) :
	function bizness_page_menu_args( $args ) {
		$args['show_home'] = true;
		return $args;
	}
endif;
add_filter( 'wp_page_menu_args', 'bizness_page_menu_args' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
if ( ! function_exists( 'bizness_widgets_init' ) ) :
	function bizness_widgets_init() {
		
		register_sidebar( array(
			'name' => __( 'Sidebar Right', 'bizness' ),
			'id' => 'sidebar-right',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => "</aside>",
			'before_title' => '<div class="widget-title">',
			'after_title' => '</div>',
		) );
		
		register_sidebar( array(
			'name' => __( 'Sidebar Alt_Homepage', 'bizness' ),
			'id' => 'sidebar-home',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => "</aside>",
			'before_title' => '<div class="widget-title">',
			'after_title' => '</div>',
		) );
	
	}
endif;
add_action( 'widgets_init', 'bizness_widgets_init' );

if ( ! function_exists( 'bizness_content_nav' ) ):
/**
 * Display navigation to next/previous pages when applicable
 */
function bizness_content_nav( $nav_id ) {
	global $wp_query;

	?>
	<nav id="<?php echo $nav_id; ?>">
		<h1 class="assistive-text section-heading"><?php _e( 'Post navigation', 'bizness' ); ?></h1>

	<?php if ( is_single() ) : // navigation links for single posts ?>

		<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr; Previous', 'Previous post link', 'bizness' ) . '</span>' ); ?>
		<?php next_post_link( '<div class="nav-next">%link</div>', '<span class="meta-nav">' . _x( 'Next &rarr;', 'Next post link', 'bizness' ) . '</span>' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'bizness' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'bizness' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav><!-- #<?php echo $nav_id; ?> -->
	<?php
}
endif;


if ( ! function_exists( 'bizness_comment' ) ) :
/**
 * Template for comments and pingbacks.
 */
function bizness_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'bizness' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'bizness' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>">
			<footer class="clearfix comment-head">
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, 50 ); ?>
					<?php printf( __( '%s', 'bizness' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div><!-- .comment-author .vcard -->
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em><?php _e( 'Your comment is awaiting moderation.', 'bizness' ); ?></em>
					<br />
				<?php endif; ?>

				<div class="comment-meta commentmetadata">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time pubdate datetime="<?php comment_time( 'c' ); ?>">
					<?php
						/* translators: 1: date, 2: time */
						printf( __( '%1$s at %2$s', 'bizness' ), get_comment_date(), get_comment_time() ); ?>
					</time></a>
					<?php edit_comment_link( __( '(Edit)', 'bizness' ), ' ' );
					?>
				</div><!-- .comment-meta .commentmetadata -->
			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif;

if ( ! function_exists( 'bizness_recent_comments' ) ) :
	function bizness_recent_comments($no_comments = 10, $comment_len = 80, $avatar_size = 48) {
		$comments_query = new WP_Comment_Query();
		$comments = $comments_query->query( array( 'number' => $no_comments ) );
		$comm = '';
		if ( $comments ) : foreach ( $comments as $comment ) :
		$comm .= '<li>';
		$comm .= '<a class="author" href="' . get_permalink( $comment->comment_post_ID ) . '#comment-' . $comment->comment_ID . '"><strong>';		$comm .= get_comment_author( $comment->comment_ID ) . ':</strong></a> ';

		$comm .= strip_tags( substr( apply_filters( 'get_comment_text', $comment->comment_content ), 0, $comment_len ) ) . '</li>';
		endforeach; else :
		$comm .= 'No comments.';
		endif;
		echo $comm;	
	}
endif;

if ( ! function_exists( 'bizness_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function bizness_posted_on() {
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a><span class="byline"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'bizness' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'bizness' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
}
endif;

/**
 * Adds custom classes to the array of body classes.
 */
if ( ! function_exists( 'bizness_body_classes' ) ) :
function bizness_body_classes( $classes ) {
	// Adds a class of single-author to blogs with only 1 published author
	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}

	return $classes;
}
endif;
add_filter( 'body_class', 'bizness_body_classes' );

/**
 * Returns true if a blog has more than 1 category
 */
if ( ! function_exists( 'bizness_categorized_blog' ) ) :
	function bizness_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
			// Create an array of all the categories that are attached to posts
			$all_the_cool_cats = get_categories( array(
				'hide_empty' => 1,
			) );
	
			// Count the number of categories that are attached to the posts
			$all_the_cool_cats = count( $all_the_cool_cats );
	
			set_transient( 'all_the_cool_cats', $all_the_cool_cats );
		}
	
		if ( '1' != $all_the_cool_cats ) {
			// This blog has more than 1 category so bizness_categorized_blog should return true
			return true;
		} else {
			// This blog has only 1 category so bizness_categorized_blog should return false
			return false;
		}
	}
endif;

/**
 * Flush out the transients used in bizness_categorized_blog
 */
if ( ! function_exists( 'bizness_category_transient_flusher' ) ) :
	function bizness_category_transient_flusher() {
		// Like, beat it. Dig?
		delete_transient( 'all_the_cool_cats' );
	}
endif;
add_action( 'edit_category', 'bizness_category_transient_flusher' );
add_action( 'save_post', 'bizness_category_transient_flusher' );

/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 */
if ( ! function_exists( 'bizness_enhanced_image_navigation' ) ) :
	function bizness_enhanced_image_navigation( $url ) {
		global $post, $wp_rewrite;
	
		$id = (int) $post->ID;
		$object = get_post( $id );
		if ( wp_attachment_is_image( $post->ID ) && ( $wp_rewrite->using_permalinks() && ( $object->post_parent > 0 ) && ( $object->post_parent != $id ) ) )
			$url = $url . '#main';
	
		return $url;
	}
endif;
add_filter( 'attachment_link', 'bizness_enhanced_image_navigation' );


if ( ! function_exists( 'bizness_pagination' ) ) :
	function bizness_pagination($pages = '', $range = 4)
	{
		 $showitems = ($range * 2)+1; 
	 
		 global $paged;
		 if(empty($paged)) $paged = 1;
	 
		 if($pages == '')
		 {
			 global $wp_query;
			 $pages = $wp_query->max_num_pages;
			 if(!$pages)
			 {
				 $pages = 1;
			 }
		 }  
	 
		 if(1 != $pages)
		 {
			 printf( __( '<div class="pagination"><span>Page %1$s of %2$s</span>', 'bizness'), $paged, $pages );
			 if($paged > 2 && $paged > $range+1 && $showitems < $pages) printf( __( '<a href="%1$s">&laquo; First</a>', 'bizness' ), get_pagenum_link(1) );
			 if($paged > 1 && $showitems < $pages) printf( __( '<a href="%1$s">&lsaquo; Previous</a>', 'bizness' ), get_pagenum_link($paged - 1) );
	 
			 for ($i=1; $i <= $pages; $i++)
			 {
				 if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
				 {
					 echo ($paged == $i)? "<span class=\"current\">".$i."</span>":"<a href='".get_pagenum_link($i)."' class=\"inactive\">".$i."</a>";
				 }
			 }
	 
			 if ($paged < $pages && $showitems < $pages) printf( __( '<a href="%1$s">Next &rsaquo;</a>', 'bizness' ), get_pagenum_link($paged + 1) );
			 if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) printf( __( '<a href="%1$s">Last &raquo;</a>', 'bizness' ), get_pagenum_link($pages) );
			 echo "</div>\n";
		 }
	}
endif;

if ( ! function_exists( 'bizness_excerpt' ) ) :
	function bizness_excerpt($limit) {
		$excerpt = explode(' ', get_the_excerpt(), $limit);
		if (count($excerpt)>=$limit) {
		array_pop($excerpt);
		$excerpt = implode(" ",$excerpt).'...';
		} else {
		$excerpt = implode(" ",$excerpt);
		}	
		$excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
		return $excerpt;
	}
endif;


if ( ! function_exists( 'bizness_w3c_valid_rel' ) ) :
	function bizness_w3c_valid_rel( $text ) {
		$text = str_replace('rel="category tag"', 'rel="tag"', $text); return $text; 
	}
endif;
add_filter( 'the_category', 'bizness_w3c_valid_rel' );

if ( ! function_exists( 'bizness_modernizr_addclass' ) ) :
	function bizness_modernizr_addclass($output) {
		return $output . ' class="no-js"';
	}
endif;
add_filter('language_attributes', 'bizness_modernizr_addclass');

if ( ! function_exists( 'bizness_modernizr_script' ) ) :
	function bizness_modernizr_script() {
		wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/library/js/modernizr-2.6.2.min.js', false, '2.6.2');
	}    
endif;
add_action('wp_enqueue_scripts', 'bizness_modernizr_script');

if ( ! function_exists( 'bizness_custom_scripts' ) ) :
	function bizness_custom_scripts() {
		wp_enqueue_script( 'bizness_cycle_js', get_template_directory_uri() . '/library/js/jquery.cycle2.min.js', array( 'jquery' ), '20130202' );
		wp_enqueue_script( 'bizness_cycle_tile_js', get_template_directory_uri() . '/library/js/jquery.cycle2.tile.min.js', array( 'jquery' ), '20121120' );
		wp_enqueue_script( 'bizness_cycle_scrollvert_js', get_template_directory_uri() . '/library/js/jquery.cycle2.scrollVert.min.js', array( 'jquery' ), '20121120' );
		wp_enqueue_script( 'bizness_custom_js', get_template_directory_uri() . '/library/js/scripts.js', array( 'jquery' ), '1.0.0' );
		wp_enqueue_style( 'bizness_style', get_stylesheet_uri() );
	}
endif;
add_action('wp_enqueue_scripts', 'bizness_custom_scripts');

?>